@@ -53,7 +53,7 @@
 #include <gtk/gtksignal.h>
 
 /* Must be before all other gnome includes!! */
-#include "gnome-i18nP.h"
+#include <glib/gi18n-lib.h>
 
 #include <libgnome/gnome-util.h>
 #include "libgnomeuiP.h"
@@ -134,7 +134,7 @@ gnome_file_entry_get_type (void)
 	static GType object_type = 0;
 
 	if (object_type == 0) {
-		static const GTypeInfo object_info = {
+		const GTypeInfo object_info = {
 			sizeof (GnomeFileEntryClass),
 			(GBaseInitFunc) NULL,
 			(GBaseFinalizeFunc) NULL,
@@ -147,7 +147,7 @@ gnome_file_entry_get_type (void)
 			NULL			/* value_table */
 		};
 
-		static const GInterfaceInfo editable_info = {
+		const GInterfaceInfo editable_info = {
 			(GInterfaceInitFunc) gnome_file_entry_editable_init,	 /* interface_init */
 			NULL,			                         	 /* interface_finalize */
 			NULL			                         	 /* interface_data */
@@ -594,6 +594,7 @@ browse_clicked(GnomeFileEntry *fentry)
 	char *p;
 	GtkWidget *toplevel;
 	GClosure *closure;
+	gboolean modal_fentry = FALSE;
 
 	/*if it already exists make sure it's shown and raised*/
 	if (fentry->fsw) {
@@ -716,12 +717,14 @@ browse_clicked(GnomeFileEntry *fentry)
 
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (fentry));
 
-	if (GTK_WIDGET_TOPLEVEL (toplevel) && GTK_IS_WINDOW (toplevel))
+	if (GTK_WIDGET_TOPLEVEL (toplevel) && GTK_IS_WINDOW (toplevel)) {
 		gtk_window_set_transient_for (GTK_WINDOW (fw), GTK_WINDOW(toplevel));
+		modal_fentry = gtk_window_get_modal (GTK_WINDOW (toplevel));
+	}
 
 	g_object_set_data (G_OBJECT (fw), "gnome_file_entry", fentry);
 
-	if (fentry->_priv->is_modal)
+	if (fentry->_priv->is_modal || modal_fentry)
 		gtk_window_set_modal (GTK_WINDOW (fw), TRUE);
 
 	gtk_widget_show (fw);
@@ -786,13 +789,10 @@ gnome_file_entry_drag_data_received (GtkWidget        *widget,
 	gtk_entry_set_text (GTK_ENTRY (entry), file);
 }
 
-#define ELEMENTS(x) (sizeof (x) / sizeof (x[0]))
-
 static void
 gnome_file_entry_init (GnomeFileEntry *fentry)
 {
 	GtkWidget *button, *the_gtk_entry;
-	static GtkTargetEntry drop_types[] = { { "text/uri-list", 0, 0 } };
 	GtkWidget *hbox;
 
 	gtk_box_set_spacing (GTK_BOX (fentry), 4);
@@ -829,7 +829,9 @@ gnome_file_entry_init (GnomeFileEntry *fentry)
 			   GTK_DEST_DEFAULT_MOTION |
 			   GTK_DEST_DEFAULT_HIGHLIGHT |
 			   GTK_DEST_DEFAULT_DROP,
-			   drop_types, ELEMENTS (drop_types), GDK_ACTION_COPY);
+			   NULL, 0,
+                           GDK_ACTION_COPY);
+        gtk_drag_dest_add_uri_targets (GTK_WIDGET (fentry));
 
 	g_signal_connect (fentry, "drag_data_received",
 			  G_CALLBACK (gnome_file_entry_drag_data_received),
@@ -984,9 +986,7 @@ gnome_file_entry_set_title (GnomeFileEntry *fentry, const char *browse_dialog_ti
 	g_return_if_fail (fentry != NULL);
 	g_return_if_fail (GNOME_IS_FILE_ENTRY (fentry));
 
-	if (fentry->_priv->browse_dialog_title)
-		g_free (fentry->_priv->browse_dialog_title);
-
+	g_free (fentry->_priv->browse_dialog_title);
 	fentry->_priv->browse_dialog_title = g_strdup (browse_dialog_title); /* handles NULL correctly */
 }
 
@@ -1003,12 +1003,21 @@ gnome_file_entry_set_title (GnomeFileEntry *fentry, const char *browse_dialog_ti
 void
 gnome_file_entry_set_default_path(GnomeFileEntry *fentry, const char *path)
 {
+#ifdef MAXPATHLEN
 	char rpath[MAXPATHLEN+1];
+#else
+	char *rpath;
+#endif
 	char *p;
 	g_return_if_fail (fentry != NULL);
 	g_return_if_fail (GNOME_IS_FILE_ENTRY (fentry));
 
+#ifdef MAXPATHLEN
 	if(path && realpath(path, rpath))
+#else
+	rpath = realpath(path, NULL);
+	if(path && rpath)
+#endif
 		p = g_strdup(rpath);
 	else
 		p = NULL;
