@@ -21,8 +21,9 @@
 #ifndef GNOME_FONT_PICKER_H
 #define GNOME_FONT_PICKER_H
 
-#include <gtk/gtkbutton.h>
+#ifndef GNOME_DISABLE_DEPRECATED
 
+#include <gtk/gtkbutton.h>
 
 G_BEGIN_DECLS
 
@@ -37,7 +38,6 @@ typedef enum {
     GNOME_FONT_PICKER_MODE_UNKNOWN
 } GnomeFontPickerMode;
         
-
 #define GNOME_TYPE_FONT_PICKER            (gnome_font_picker_get_type ())
 #define GNOME_FONT_PICKER(obj)            (GTK_CHECK_CAST ((obj), GNOME_TYPE_FONT_PICKER, GnomeFontPicker))
 #define GNOME_FONT_PICKER_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), GNOME_TYPE_FONT_PICKER, GnomeFontPickerClass))
@@ -103,9 +103,7 @@ GtkWidget * gnome_font_picker_uw_get_widget    (GnomeFontPicker *gfp);
 /* Functions to interface with GtkFontSelectionDialog */
 const gchar* gnome_font_picker_get_font_name  (GnomeFontPicker *gfp);
 
-#ifndef GTK_DISABLE_DEPRECATED
 GdkFont*   gnome_font_picker_get_font	      (GnomeFontPicker *gfp);
-#endif /* GTK_DISABLE_DEPRECATED */
 
 gboolean   gnome_font_picker_set_font_name    (GnomeFontPicker *gfp,
                                                const gchar     *fontname);
@@ -115,8 +113,9 @@ const gchar* gnome_font_picker_get_preview_text (GnomeFontPicker *gfp);
 void	   gnome_font_picker_set_preview_text (GnomeFontPicker *gfp,
                                                const gchar     *text);
 
-
 G_END_DECLS
 
-    
+#endif /* GTK_DISABLE_DEPRECATED */
+
 #endif /* GNOME_FONT_PICKER_H */
+
